@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.15'; # VERSION
 
 
 use 5.006;
@@ -131,7 +131,7 @@ sub _preload_module
     join ',', 
     # quotemeta is overkill, but it will make sure that characters
     # like " are quoted
-    map { '"' . quotemeta . '"' }
+    map { '"' . quotemeta($_) . '"' }
     grep { ! ref } @INC)
       || die "unable to write $filename: $!";
   close($fh) || die "unable to close $filename: $!";;
@@ -267,7 +267,7 @@ sub _script {
   }
   if ( _ARRAY($in) ) {
     unless ( scalar grep { not defined _STRING($_) } @$in ) {
-      return $in;     
+      return [ @$in ];
     }
   }
   Carp::croak("Invalid command parameter");
@@ -315,7 +315,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.12
+version 1.15
 
 =head1 SYNOPSIS
 
@@ -522,6 +522,10 @@ Original author: Adam Kennedy
 
 Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
+Contributors:
+
+Brendan Byrd
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2006 by Adam Kennedy.
